@@ -4,6 +4,6 @@ var searchData=
   ['names_20dw_5ftag_5fmember_20etc_20as_20strings_1',['Names DW_TAG_member etc as strings',['../group___naming.html',1,'']]],
   ['no_20object_20file_20present_2',['Reading DWARF with no object file present',['../index.html#dwsec_noobj',1,'']]],
   ['nonstandard_3',['nonstandard',['../group__examplej.html',1,'Reading .debug_funcnames (nonstandard)'],['../group__examplel.html',1,'Reading .debug_types (nonstandard)'],['../group__examplen.html',1,'Reading .debug_varnames data (nonstandard)'],['../group__exampleh.html',1,'Reading .debug_weaknames (nonstandard)']]],
-  ['number_4',['DW_DLA alloc/dealloc typename&amp;number',['../group__dwdla.html',1,'']]],
+  ['number_4',['DW_DLA alloc/dealloc typename&amp;amp;number',['../group__dwdla.html',1,'']]],
   ['numbers_5',['DW_DLE Dwarf_Error numbers',['../group__dwdle.html',1,'']]]
 ];
